%CODIFICADOR EN BITS.
%function a=bitcod(LARc,Nc,bc,Mc,xmaxc,xmc)
%Entradas:
%LARc:LAR codificados.
%Nc:términos de autocorrelación codificados.
%bc:ganancias de autocorrelación codificados.
%Mc:posiciones RPE codificadas.
%xmaxc:valores máximos RPE codificados.
%xmc:subsecuencia seleccionada codificada.
%Salidas:
%a:260 bits de salida de los parámetros codificados.
function a=bitcod(LARc,Nc,bc,Mc,xmaxc,xmc)
bits=[6 6 5 5 4 4 3 3];%el peso de codificación de cada LAR es distinto.
if(LARc(1)>=0) 
   a=dec2bin(LARc(1),bits(1));
else 
   a=dec2bin(bitcmp(abs(LARc(1)),bits(1))+1,bits(1));
end
for i=2:8;
	if(LARc(i)>=0) 
   	a=[a,dec2bin(LARc(i),bits(i))];
	else 
   	a=[a,dec2bin(bitcmp(abs(LARc(i)),bits(i))+1,bits(i))];
	end
end
for i=1:4
   a=[a,dec2bin(Nc(i),7)];
   a=[a,dec2bin(bc(i),2)];
   a=[a,dec2bin(Mc(i),2)];
   a=[a,dec2bin(xmaxc(i),6)];
   for j=1:13
      a=[a,dec2bin(xmc(13*(i-1)+j),3)];
   end
end